@@ -1,9 +1,8 @@
 package Template::Mustache;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Drawing Mustaches on Perl for fun and profit
-$Template::Mustache::VERSION = '1.0.1_0'; # TRIAL
-
-$Template::Mustache::VERSION = '1.0.10';use 5.12.0;
+$Template::Mustache::VERSION = '1.0.2';
+use 5.12.0;
 
 use Moo;
 use MooseX::MungeHas { has_rw => [ 'is_rw' ], has_ro => [ 'is_ro' ] };
@@ -358,7 +357,7 @@ Template::Mustache - Drawing Mustaches on Perl for fun and profit
 
 =head1 VERSION
 
-version 1.0.1_0
+version 1.0.2
 
 =head1 SYNOPSIS
 
