@@ -1,8 +1,7 @@
 package Template::Mustache::Token::Partial;
 our $AUTHORITY = 'cpan:YANICK';
-$Template::Mustache::Token::Partial::VERSION = '1.0.1_0'; # TRIAL
-
-$Template::Mustache::Token::Partial::VERSION = '1.0.10';use Moo;
+$Template::Mustache::Token::Partial::VERSION = '1.0.2';
+use Moo;
 
 use MooseX::MungeHas { has_ro => [ 'is_ro' ], has_rw => [ 'is_rw' ] };
 
@@ -41,7 +40,7 @@ Template::Mustache::Token::Partial
 
 =head1 VERSION
 
-version 1.0.1_0
+version 1.0.2
 
 =head1 AUTHORS
 
