@@ -1,8 +1,7 @@
 package Template::Mustache::Token::Section;
 our $AUTHORITY = 'cpan:YANICK';
-$Template::Mustache::Token::Section::VERSION = '1.0.1_0'; # TRIAL
-
-$Template::Mustache::Token::Section::VERSION = '1.0.10';use Moo;
+$Template::Mustache::Token::Section::VERSION = '1.0.2';
+use Moo;
 
 use MooseX::MungeHas { has_ro => [ 'is_ro' ] };
 
@@ -63,7 +62,7 @@ Template::Mustache::Token::Section
 
 =head1 VERSION
 
-version 1.0.1_0
+version 1.0.2
 
 =head1 AUTHORS
 
