@@ -1,8 +1,7 @@
 package Template::Mustache::Token::Variable;
 our $AUTHORITY = 'cpan:YANICK';
-$Template::Mustache::Token::Variable::VERSION = '1.0.1_0'; # TRIAL
-
-$Template::Mustache::Token::Variable::VERSION = '1.0.10';use Escape::Houdini qw/ escape_html /;
+$Template::Mustache::Token::Variable::VERSION = '1.0.2';
+use Escape::Houdini qw/ escape_html /;
 use Scalar::Util qw/ looks_like_number /;
 
 use Moo;
@@ -58,7 +57,7 @@ Template::Mustache::Token::Variable
 
 =head1 VERSION
 
-version 1.0.1_0
+version 1.0.2
 
 =head1 AUTHORS
 
