@@ -1,9 +1,8 @@
 package Template::Mustache::Trait;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: turn an attribute into a Mustache template
-$Template::Mustache::Trait::VERSION = '1.0.1_0'; # TRIAL
+$Template::Mustache::Trait::VERSION = '1.0.2';
 
-$Template::Mustache::Trait::VERSION = '1.0.10';
 use Moose::Role;
 
 use Template::Mustache;
@@ -24,9 +23,8 @@ before _process_options => sub {
 
 package Moose::Meta::Attribute::Custom::Trait::Mustache;
 our $AUTHORITY = 'cpan:YANICK';
-$Moose::Meta::Attribute::Custom::Trait::Mustache::VERSION = '1.0.1_0'; # TRIAL
-
-$Moose::Meta::Attribute::Custom::Trait::Mustache::VERSION = '1.0.10';sub register_implementation { 'Template::Mustache::Trait' }
+$Moose::Meta::Attribute::Custom::Trait::Mustache::VERSION = '1.0.2';
+sub register_implementation { 'Template::Mustache::Trait' }
 
 
 1;
@@ -43,7 +41,7 @@ Template::Mustache::Trait - turn an attribute into a Mustache template
 
 =head1 VERSION
 
-version 1.0.1_0
+version 1.0.2
 
 =head1 SYNOPSIS
 
